#!/usr/bin/env bash
# Do - The Simplest Build Tool on Earth.
# Documentation and examples see https://github.com/8gears/do

set -Eeuo pipefail # -e "Automatic exit from bash shell script on error"  -u "Treat unset variables and parameters as errors"

build() {
  echo "I am ${FUNCNAME[0]}ing"
  go version
  go build
}

test() {
  echo "I am ${FUNCNAME[0]}ing"
  _lint && _vet && _test
}

run() {
  echo "I am ${FUNCNAME[0]}ing"
  fmt && test && go run main.go
}

fmt() {
  echo "I am ${FUNCNAME[0]}ing"
  go fmt ./...
}

_test() {
  go test -v -coverprofile=coverage.out -covermode count ./... | tee tests.out
}

_testhtml() {
  _test && go tool cover -html=coverage.out
}

_lint() {
  golint -set_exit_status ./...
}

_vet() {
  go vet ./...
}

all() {
  fmt && test && build
}

"$@" # <- execute the task

[ "$#" -gt 0 ] || printf "Usage:\n\t./do.sh %s\n" "($(compgen -A function | grep '^[^_]' | paste -sd '|' -))"
